@@ -64,11 +64,11 @@ class Git(ShellCommand):
         self.create_branch(branch, remote_branch)
 
     def _parse_output(self, out):
-        output = [l.strip() for l in out.split("\n") if l]
+        output = [o.strip() for o in out.split("\n") if o]
         return output
 
     def _parse_branch_output(self, out):
-        output = [l for l in self._parse_output(out) if l.find('HEAD') < 0]
+        output = [o for o in self._parse_output(out) if o.find('HEAD') < 0]
         return output
 
     def remote_branches(self, remote=""):
@@ -236,7 +236,7 @@ class Git(ShellCommand):
                '--format="%H %ct"']
         if not branch:
             return []
-        out = self(*cmd, log_cmd=True, log_fail=True, fatal=True)
+        out = self(*cmd, log_cmd=False, log_fail=False, fatal=False)
         out = out.replace('"', '')
         if not out:
             return []
